@@ -1,5 +1,4 @@
 import io
-import os
 from typing import BinaryIO
 
 from Cryptodome.Cipher import AES
@@ -11,6 +10,9 @@ KEY_SIZE = 32  # size of AES key in bytes
 AES_MODE = AES.MODE_CBC  # cipher block chaining
 CHUNK_SIZE = 2 ** 30  # 1 GB # chunk size to read from io in bytes
 
+assert BLOCK_SIZE == 16
+assert CHUNK_SIZE % BLOCK_SIZE == 0
+
 
 def sha1_hash(f_in: BinaryIO) -> bytes:
     h = SHA1.new()
@@ -27,18 +29,19 @@ def aes256_encrypt(
         key: bytes, init_vec: bytes,
         plain_read_io: BinaryIO, encrypted_write_io: BinaryIO,
 ):
-    assert BLOCK_SIZE == 16
-    assert CHUNK_SIZE % BLOCK_SIZE == 0
     assert len(init_vec) == BLOCK_SIZE
     assert len(key) == KEY_SIZE
+
     aes = AES.new(key, AES_MODE, init_vec)
     while True:
         chunk = plain_read_io.read(CHUNK_SIZE)
         if len(chunk) == 0:
             return
         if len(chunk) % BLOCK_SIZE != 0:
-            chunk += b"\0" * (BLOCK_SIZE - len(chunk) % BLOCK_SIZE)  # padded with 0s until BLOCK_SIZE
+            chunk += b"\0" * (BLOCK_SIZE - len(chunk) % BLOCK_SIZE)  # pad 0s until multiples of BLOCK_SIZE
+
         b = aes.encrypt(chunk)
+
         encrypted_write_io.write(b)
 
 
@@ -46,37 +49,22 @@ def aes256_decrypt(
         key: bytes, init_vec: bytes, file_size: int,
         encrypted_read_io: BinaryIO, decrypted_write_io: BinaryIO,
 ):
-    assert BLOCK_SIZE == 16
-    assert CHUNK_SIZE % BLOCK_SIZE == 0
     assert len(init_vec) == BLOCK_SIZE
     assert len(key) == KEY_SIZE
+
     aes = AES.new(key, AES_MODE, init_vec)
     remaining_size = file_size
-    while True:
+    while remaining_size > 0:
         chunk = encrypted_read_io.read(CHUNK_SIZE)
-        if len(chunk) == 0:
-            return
+        assert len(chunk) == CHUNK_SIZE, "corrupted_file"
+
         b = aes.decrypt(chunk)
+
         if remaining_size < len(b):
             b = b[:remaining_size]
-        decrypted_write_io.write(b)
         remaining_size -= len(b)
 
-
-def read_or_create_key(key_path: str) -> bytes:
-    def read_hex_file(path: str) -> bytes:
-        with open(path, "r") as f:
-            return bytes.fromhex(f.read())
-
-    def write_hex_file(path: str, b: bytes):
-        with open(path, "w") as f:
-            f.write(b.hex())
-
-    if not os.path.exists(key_path):
-        write_hex_file(key_path, os.urandom(KEY_SIZE))
-
-    key = read_hex_file(key_path)
-    return key
+        decrypted_write_io.write(b)
 
 
 def make_key_from_password(password: bytes) -> bytes:
